![logo](docs/py-sdk-logo.svg)

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/sglib.svg)](https://pypi.python.org/pypi/pydk/)
[![PyPI version](https://badge.fury.io/py/sglib.svg)](https://badge.fury.io/py/pydk)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

A **py**thon **d**eveloper **k**it with the prerequisite python nuts-and-bolts functions to make things clean and easy.


Install with [pip](https://pypi.org/project/pydk/)
```python
pip install pydk
```

Install the development verison:
```BASH
git clone https://github.com/mvinyard/python-developer-kit.git; cd ./python-developer-kit
pip install -e .
```

---
Questions? Open an [issue](https://github.com/mvinyard/python-developer-kit/issues/new) or send an email to [Michael Vinyard](mailto:mvinyard@broadinstitute.org).
